@@ -102,12 +102,9 @@ def load_module(filename, code_objects=None, fast_load=False,
     elif osp.getsize(filename) < 50:
         raise ImportError("File name: '%s (%d bytes)' is too short to be a valid pyc file" % (filename, osp.getsize(filename)))
 
-    try:
-        fp = open(filename, 'rb')
+    with open(filename, 'rb') as fp:
         return load_module_from_file_object(fp, filename=filename, code_objects=code_objects,
                                             fast_load=fast_load, get_code=get_code)
-    finally:
-        fp.close()
 
 def load_module_from_file_object(fp, filename='<unknown>', code_objects=None, fast_load=False,
                 get_code=True):
@@ -174,7 +171,7 @@ def load_module_from_file_object(fp, filename='<unknown>', code_objects=None, fa
             # the size info, occurred within a Python major/minor
             # release. Hence the test on the magic value rather than
             # PYTHON_VERSION, although PYTHON_VERSION would probably work.
-            if 3200 <= magic_int < 20121 and magic_int not in (5892,):
+            if 3200 <= magic_int < 20121 and magic_int not in (5892, 11913, 39170, 39171):
                 source_size = unpack("<I", fp.read(4))[0] # size mod 2**32
             else:
                 source_size = None
